systemtools.Timer
=================

.. abjad-lineage:: abjad.tools.systemtools.Timer.Timer

.. autoclass:: abjad.tools.systemtools.Timer.Timer

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.systemtools.Timer.Timer.elapsed_time
      ~abjad.tools.systemtools.Timer.Timer.start_time
      ~abjad.tools.systemtools.Timer.Timer.stop_time
      ~abjad.tools.systemtools.Timer.Timer.__enter__
      ~abjad.tools.systemtools.Timer.Timer.__eq__
      ~abjad.tools.systemtools.Timer.Timer.__exit__
      ~abjad.tools.systemtools.Timer.Timer.__format__
      ~abjad.tools.systemtools.Timer.Timer.__ne__
      ~abjad.tools.systemtools.Timer.Timer.__repr__

Bases
-----

- :py:class:`abctools.ContextManager <abjad.tools.abctools.ContextManager.ContextManager>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.systemtools.Timer.Timer.elapsed_time
   :noindex:

.. autoattribute:: abjad.tools.systemtools.Timer.Timer.start_time
   :noindex:

.. autoattribute:: abjad.tools.systemtools.Timer.Timer.stop_time
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.systemtools.Timer.Timer.__enter__
   :noindex:

.. automethod:: abjad.tools.systemtools.Timer.Timer.__eq__
   :noindex:

.. automethod:: abjad.tools.systemtools.Timer.Timer.__exit__
   :noindex:

.. automethod:: abjad.tools.systemtools.Timer.Timer.__format__
   :noindex:

.. automethod:: abjad.tools.systemtools.Timer.Timer.__ne__
   :noindex:

.. automethod:: abjad.tools.systemtools.Timer.Timer.__repr__
   :noindex:
